pytilities.descriptors.attributedescriptor — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »

# pytilities.descriptors.attributedescriptor

`pytilities.descriptors.attributedescriptor.` `AttributeDescriptor`(attr_name)

  Construct a wrapper that makes an attribute look like a descriptor.

  The descriptor supports all access (get, set, del).

  Parameters: | attr_name (string) – Name of the attribute to get

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.descriptors »